import sys
import typing

GenericType = typing.TypeVar("GenericType")


class RestrictBlend:
    context = None
    ''' '''

    data = None
    ''' '''


class _RestrictContext:
    preferences = None
    ''' '''

    window_manager = None
    ''' '''


class _RestrictData:
    pass



import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def change_frame(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
                 undo: typing.Optional[bool] = None,
                 *,
                 frame: typing.Optional[typing.Any] = 0.0,
                 snap: typing.Union[bool, typing.Any] = False):
    ''' Interactively change the current frame number

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param frame: Frame
    :type frame: typing.Optional[typing.Any]
    :param snap: Snap
    :type snap: typing.Union[bool, typing.Any]
    '''

    pass


def channel_select_keys(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
                        undo: typing.Optional[bool] = None,
                        *,
                        extend: typing.Union[bool, typing.Any] = False):
    ''' Select all keyframes of channel under mouse

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param extend: Extend, Extend selection
    :type extend: typing.Union[bool, typing.Any]
    '''

    pass


def channel_view_pick(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        include_handles: typing.Union[bool, typing.Any] = True,
        use_preview_range: typing.Union[bool, typing.Any] = True):
    ''' Reset viewable area to show the channel under the cursor

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param include_handles: Include Handles, Include handles of keyframes when calculating extents
    :type include_handles: typing.Union[bool, typing.Any]
    :param use_preview_range: Use Preview Range, Ignore frames outside of the preview range
    :type use_preview_range: typing.Union[bool, typing.Any]
    '''

    pass


def channels_clean_empty(override_context: typing.
                         Union[typing.Dict, 'bpy.types.Context'] = None,
                         execution_context: typing.Union[str, int] = None,
                         undo: typing.Optional[bool] = None):
    ''' Delete all empty animation data containers from visible data-blocks

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def channels_click(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
                   undo: typing.Optional[bool] = None,
                   *,
                   extend: typing.Union[bool, typing.Any] = False,
                   children_only: typing.Union[bool, typing.Any] = False):
    ''' Handle mouse clicks over animation channels

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param extend: Extend Select
    :type extend: typing.Union[bool, typing.Any]
    :param children_only: Select Children Only
    :type children_only: typing.Union[bool, typing.Any]
    '''

    pass


def channels_collapse(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
                      undo: typing.Optional[bool] = None,
                      *,
                      all: typing.Union[bool, typing.Any] = True):
    ''' Collapse (close) all selected expandable animation channels

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param all: All, Collapse all channels (not just selected ones)
    :type all: typing.Union[bool, typing.Any]
    '''

    pass


def channels_delete(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
                    undo: typing.Optional[bool] = None):
    ''' Delete all selected animation channels

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def channels_editable_toggle(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
                             undo: typing.Optional[bool] = None,
                             *,
                             mode: typing.Optional[typing.Any] = 'TOGGLE',
                             type: typing.Optional[typing.Any] = 'PROTECT'):
    ''' Toggle editability of selected channels

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param mode: Mode
    :type mode: typing.Optional[typing.Any]
    :param type: Type
    :type type: typing.Optional[typing.Any]
    '''

    pass


def channels_expand(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
                    undo: typing.Optional[bool] = None,
                    *,
                    all: typing.Union[bool, typing.Any] = True):
    ''' Expand (open) all selected expandable animation channels

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param all: All, Expand all channels (not just selected ones)
    :type all: typing.Union[bool, typing.Any]
    '''

    pass


def channels_fcurves_enable(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
                            undo: typing.Optional[bool] = None):
    ''' Clear 'disabled' tag from all F-Curves to get broken F-Curves working again

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def channels_group(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
                   undo: typing.Optional[bool] = None,
                   *,
                   name: typing.Union[str, typing.Any] = "New Group"):
    ''' Add selected F-Curves to a new group

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param name: Name, Name of newly created group
    :type name: typing.Union[str, typing.Any]
    '''

    pass


def channels_move(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
                  undo: typing.Optional[bool] = None,
                  *,
                  direction: typing.Optional[typing.Any] = 'DOWN'):
    ''' Rearrange selected animation channels

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param direction: Direction
    :type direction: typing.Optional[typing.Any]
    '''

    pass


def channels_rename(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
                    undo: typing.Optional[bool] = None):
    ''' Rename animation channel under mouse

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def channels_select_all(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
                        undo: typing.Optional[bool] = None,
                        *,
                        action: typing.Optional[typing.Any] = 'TOGGLE'):
    ''' Toggle selection of all animation channels

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle -- Toggle selection for all elements. * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements. * ``INVERT`` Invert -- Invert selection of all elements.
    :type action: typing.Optional[typing.Any]
    '''

    pass


def channels_select_box(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
                        undo: typing.Optional[bool] = None,
                        *,
                        xmin: typing.Optional[typing.Any] = 0,
                        xmax: typing.Optional[typing.Any] = 0,
                        ymin: typing.Optional[typing.Any] = 0,
                        ymax: typing.Optional[typing.Any] = 0,
                        wait_for_input: typing.Union[bool, typing.Any] = True,
                        deselect: typing.Union[bool, typing.Any] = False,
                        extend: typing.Union[bool, typing.Any] = True):
    ''' Select all animation channels within the specified region

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param xmin: X Min
    :type xmin: typing.Optional[typing.Any]
    :param xmax: X Max
    :type xmax: typing.Optional[typing.Any]
    :param ymin: Y Min
    :type ymin: typing.Optional[typing.Any]
    :param ymax: Y Max
    :type ymax: typing.Optional[typing.Any]
    :param wait_for_input: Wait for Input
    :type wait_for_input: typing.Union[bool, typing.Any]
    :param deselect: Deselect, Deselect rather than select items
    :type deselect: typing.Union[bool, typing.Any]
    :param extend: Extend, Extend selection instead of deselecting everything first
    :type extend: typing.Union[bool, typing.Any]
    '''

    pass


def channels_select_filter(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
                           undo: typing.Optional[bool] = None):
    ''' Start entering text which filters the set of channels shown to only include those with matching names

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def channels_setting_disable(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
                             undo: typing.Optional[bool] = None,
                             *,
                             mode: typing.Optional[typing.Any] = 'DISABLE',
                             type: typing.Optional[typing.Any] = 'PROTECT'):
    ''' Disable specified setting on all selected animation channels

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param mode: Mode
    :type mode: typing.Optional[typing.Any]
    :param type: Type
    :type type: typing.Optional[typing.Any]
    '''

    pass


def channels_setting_enable(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
                            undo: typing.Optional[bool] = None,
                            *,
                            mode: typing.Optional[typing.Any] = 'ENABLE',
                            type: typing.Optional[typing.Any] = 'PROTECT'):
    ''' Enable specified setting on all selected animation channels

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param mode: Mode
    :type mode: typing.Optional[typing.Any]
    :param type: Type
    :type type: typing.Optional[typing.Any]
    '''

    pass


def channels_setting_toggle(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
                            undo: typing.Optional[bool] = None,
                            *,
                            mode: typing.Optional[typing.Any] = 'TOGGLE',
                            type: typing.Optional[typing.Any] = 'PROTECT'):
    ''' Toggle specified setting on all selected animation channels

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param mode: Mode
    :type mode: typing.Optional[typing.Any]
    :param type: Type
    :type type: typing.Optional[typing.Any]
    '''

    pass


def channels_ungroup(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
                     undo: typing.Optional[bool] = None):
    ''' Remove selected F-Curves from their current groups

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def channels_view_selected(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        include_handles: typing.Union[bool, typing.Any] = True,
        use_preview_range: typing.Union[bool, typing.Any] = True):
    ''' Reset viewable area to show the selected channels

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param include_handles: Include Handles, Include handles of keyframes when calculating extents
    :type include_handles: typing.Union[bool, typing.Any]
    :param use_preview_range: Use Preview Range, Ignore frames outside of the preview range
    :type use_preview_range: typing.Union[bool, typing.Any]
    '''

    pass


def clear_useless_actions(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
                          undo: typing.Optional[bool] = None,
                          *,
                          only_unused: typing.Union[bool, typing.Any] = True):
    ''' Mark actions with no F-Curves for deletion after save and reload of file preserving "action libraries"

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param only_unused: Only Unused, Only unused (Fake User only) actions get considered
    :type only_unused: typing.Union[bool, typing.Any]
    '''

    pass


def copy_driver_button(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
                       undo: typing.Optional[bool] = None):
    ''' Copy the driver for the highlighted button

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def driver_button_add(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
                      undo: typing.Optional[bool] = None):
    ''' Add driver for the property under the cursor

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def driver_button_edit(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
                       undo: typing.Optional[bool] = None):
    ''' Edit the drivers for the connected property represented by the highlighted button

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def driver_button_remove(override_context: typing.
                         Union[typing.Dict, 'bpy.types.Context'] = None,
                         execution_context: typing.Union[str, int] = None,
                         undo: typing.Optional[bool] = None,
                         *,
                         all: typing.Union[bool, typing.Any] = True):
    ''' Remove the driver(s) for the connected property(s) represented by the highlighted button

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param all: All, Delete drivers for all elements of the array
    :type all: typing.Union[bool, typing.Any]
    '''

    pass


def end_frame_set(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
                  undo: typing.Optional[bool] = None):
    ''' Set the current frame as the preview or scene end frame

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def keyframe_clear_button(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
                          undo: typing.Optional[bool] = None,
                          *,
                          all: typing.Union[bool, typing.Any] = True):
    ''' Clear all keyframes on the currently active property

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param all: All, Clear keyframes from all elements of the array
    :type all: typing.Union[bool, typing.Any]
    '''

    pass


def keyframe_clear_v3d(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
                       undo: typing.Optional[bool] = None):
    ''' Remove all keyframe animation for selected objects

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def keyframe_delete(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
                    undo: typing.Optional[bool] = None,
                    *,
                    type: typing.Union[str, int, typing.Any] = 'DEFAULT'):
    ''' Delete keyframes on the current frame for all properties in the specified Keying Set

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param type: Keying Set, The Keying Set to use
    :type type: typing.Union[str, int, typing.Any]
    '''

    pass


def keyframe_delete_button(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
                           undo: typing.Optional[bool] = None,
                           *,
                           all: typing.Union[bool, typing.Any] = True):
    ''' Delete current keyframe of current UI-active property

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param all: All, Delete keyframes from all elements of the array
    :type all: typing.Union[bool, typing.Any]
    '''

    pass


def keyframe_delete_by_name(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
                            undo: typing.Optional[bool] = None,
                            *,
                            type: typing.Union[str, typing.Any] = ""):
    ''' Alternate access to 'Delete Keyframe' for keymaps to use

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param type: Keying Set, The Keying Set to use
    :type type: typing.Union[str, typing.Any]
    '''

    pass


def keyframe_delete_v3d(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
                        undo: typing.Optional[bool] = None):
    ''' Remove keyframes on current frame for selected objects and bones

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def keyframe_insert(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
                    undo: typing.Optional[bool] = None,
                    *,
                    type: typing.Union[str, int, typing.Any] = 'DEFAULT'):
    ''' Insert keyframes on the current frame for all properties in the specified Keying Set

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param type: Keying Set, The Keying Set to use
    :type type: typing.Union[str, int, typing.Any]
    '''

    pass


def keyframe_insert_button(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
                           undo: typing.Optional[bool] = None,
                           *,
                           all: typing.Union[bool, typing.Any] = True):
    ''' Insert a keyframe for current UI-active property

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param all: All, Insert a keyframe for all element of the array
    :type all: typing.Union[bool, typing.Any]
    '''

    pass


def keyframe_insert_by_name(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
                            undo: typing.Optional[bool] = None,
                            *,
                            type: typing.Union[str, typing.Any] = ""):
    ''' Alternate access to 'Insert Keyframe' for keymaps to use

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param type: Keying Set, The Keying Set to use
    :type type: typing.Union[str, typing.Any]
    '''

    pass


def keyframe_insert_menu(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        type: typing.Union[str, int, typing.Any] = 'DEFAULT',
        always_prompt: typing.Union[bool, typing.Any] = False):
    ''' Insert Keyframes for specified Keying Set, with menu of available Keying Sets if undefined

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param type: Keying Set, The Keying Set to use
    :type type: typing.Union[str, int, typing.Any]
    :param always_prompt: Always Show Menu
    :type always_prompt: typing.Union[bool, typing.Any]
    '''

    pass


def keying_set_active_set(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        type: typing.Union[str, int, typing.Any] = 'DEFAULT'):
    ''' Set a new active keying set

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param type: Keying Set, The Keying Set to use
    :type type: typing.Union[str, int, typing.Any]
    '''

    pass


def keying_set_add(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
                   undo: typing.Optional[bool] = None):
    ''' Add a new (empty) keying set to the active Scene

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def keying_set_export(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
                      undo: typing.Optional[bool] = None,
                      *,
                      filepath: typing.Union[str, typing.Any] = "",
                      filter_folder: typing.Union[bool, typing.Any] = True,
                      filter_text: typing.Union[bool, typing.Any] = True,
                      filter_python: typing.Union[bool, typing.Any] = True):
    ''' Export Keying Set to a python script

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param filepath: filepath
    :type filepath: typing.Union[str, typing.Any]
    :param filter_folder: Filter folders
    :type filter_folder: typing.Union[bool, typing.Any]
    :param filter_text: Filter text
    :type filter_text: typing.Union[bool, typing.Any]
    :param filter_python: Filter python
    :type filter_python: typing.Union[bool, typing.Any]
    '''

    pass


def keying_set_path_add(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
                        undo: typing.Optional[bool] = None):
    ''' Add empty path to active keying set

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def keying_set_path_remove(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
                           undo: typing.Optional[bool] = None):
    ''' Remove active Path from active keying set

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def keying_set_remove(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
                      undo: typing.Optional[bool] = None):
    ''' Remove the active keying set

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def keyingset_button_add(override_context: typing.
                         Union[typing.Dict, 'bpy.types.Context'] = None,
                         execution_context: typing.Union[str, int] = None,
                         undo: typing.Optional[bool] = None,
                         *,
                         all: typing.Union[bool, typing.Any] = True):
    ''' Add current UI-active property to current keying set

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param all: All, Add all elements of the array to a Keying Set
    :type all: typing.Union[bool, typing.Any]
    '''

    pass


def keyingset_button_remove(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
                            undo: typing.Optional[bool] = None):
    ''' Remove current UI-active property from current keying set

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def paste_driver_button(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
                        undo: typing.Optional[bool] = None):
    ''' Paste the driver in the clipboard to the highlighted button

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def previewrange_clear(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
                       undo: typing.Optional[bool] = None):
    ''' Clear preview range

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def previewrange_set(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
                     undo: typing.Optional[bool] = None,
                     *,
                     xmin: typing.Optional[typing.Any] = 0,
                     xmax: typing.Optional[typing.Any] = 0,
                     ymin: typing.Optional[typing.Any] = 0,
                     ymax: typing.Optional[typing.Any] = 0,
                     wait_for_input: typing.Union[bool, typing.Any] = True):
    ''' Interactively define frame range used for playback

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param xmin: X Min
    :type xmin: typing.Optional[typing.Any]
    :param xmax: X Max
    :type xmax: typing.Optional[typing.Any]
    :param ymin: Y Min
    :type ymin: typing.Optional[typing.Any]
    :param ymax: Y Max
    :type ymax: typing.Optional[typing.Any]
    :param wait_for_input: Wait for Input
    :type wait_for_input: typing.Union[bool, typing.Any]
    '''

    pass


def start_frame_set(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
                    undo: typing.Optional[bool] = None):
    ''' Set the current frame as the preview or scene start frame

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def update_animated_transform_constraints(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        use_convert_to_radians: typing.Union[bool, typing.Any] = True):
    ''' Update f-curves/drivers affecting Transform constraints (use it with files from 2.70 and earlier)

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param use_convert_to_radians: Use this only once
    :type use_convert_to_radians: typing.Union[bool, typing.Any]
    '''

    pass



import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def bbone_resize(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = (1.0, 1.0, 1.0),
        orient_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
        constraint_axis: typing.Union[typing.List[bool], typing.Any] = (False,
                                                                        False,
                                                                        False),
        mirror: typing.Union[bool, typing.Any] = False,
        release_confirm: typing.Union[bool, typing.Any] = False,
        use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Scale selected bendy bones display size

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Display Size
    :type value: typing.Optional[typing.Any]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Union[str, int, typing.Any]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Union[str, int, typing.Any]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Union[typing.List[bool], typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def bend(override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
         undo: typing.Optional[bool] = None,
         *,
         value: typing.Optional[typing.Any] = (0.0),
         mirror: typing.Union[bool, typing.Any] = False,
         use_proportional_edit: typing.Union[bool, typing.Any] = False,
         proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
         proportional_size: typing.Optional[typing.Any] = 1.0,
         use_proportional_connected: typing.Union[bool, typing.Any] = False,
         use_proportional_projected: typing.Union[bool, typing.Any] = False,
         snap: typing.Union[bool, typing.Any] = False,
         gpencil_strokes: typing.Union[bool, typing.Any] = False,
         center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
         release_confirm: typing.Union[bool, typing.Any] = False,
         use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Bend selected items between the 3D cursor and the mouse

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Union[bool, typing.Any]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Union[str, int]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Union[bool, typing.Any]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Union[bool, typing.Any]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def create_orientation(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
                       undo: typing.Optional[bool] = None,
                       *,
                       name: typing.Union[str, typing.Any] = "",
                       use_view: typing.Union[bool, typing.Any] = False,
                       use: typing.Union[bool, typing.Any] = False,
                       overwrite: typing.Union[bool, typing.Any] = False):
    ''' Create transformation orientation from selection

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param name: Name, Name of the new custom orientation
    :type name: typing.Union[str, typing.Any]
    :param use_view: Use View, Use the current view instead of the active object to create the new orientation
    :type use_view: typing.Union[bool, typing.Any]
    :param use: Use After Creation, Select orientation after its creation
    :type use: typing.Union[bool, typing.Any]
    :param overwrite: Overwrite Previous, Overwrite previously created orientation with same name
    :type overwrite: typing.Union[bool, typing.Any]
    '''

    pass


def delete_orientation(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
                       undo: typing.Optional[bool] = None):
    ''' Delete transformation orientation

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def edge_bevelweight(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
                     undo: typing.Optional[bool] = None,
                     *,
                     value: typing.Optional[typing.Any] = 0.0,
                     snap: typing.Union[bool, typing.Any] = False,
                     release_confirm: typing.Union[bool, typing.Any] = False,
                     use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Change the bevel weight of edges

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def edge_crease(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
                undo: typing.Optional[bool] = None,
                *,
                value: typing.Optional[typing.Any] = 0.0,
                snap: typing.Union[bool, typing.Any] = False,
                release_confirm: typing.Union[bool, typing.Any] = False,
                use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Change the crease of edges

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def edge_slide(override_context: typing.
               Union[typing.Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
               undo: typing.Optional[bool] = None,
               *,
               value: typing.Optional[typing.Any] = 0.0,
               single_side: typing.Union[bool, typing.Any] = False,
               use_even: typing.Union[bool, typing.Any] = False,
               flipped: typing.Union[bool, typing.Any] = False,
               use_clamp: typing.Union[bool, typing.Any] = True,
               mirror: typing.Union[bool, typing.Any] = False,
               snap: typing.Union[bool, typing.Any] = False,
               snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
               use_snap_project: typing.Union[bool, typing.Any] = False,
               snap_target: typing.Union[str, int] = 'CLOSEST',
               use_snap_self: typing.Union[bool, typing.Any] = True,
               use_snap_edit: typing.Union[bool, typing.Any] = True,
               use_snap_nonedit: typing.Union[bool, typing.Any] = True,
               use_snap_selectable: typing.Union[bool, typing.Any] = False,
               snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
               correct_uv: typing.Union[bool, typing.Any] = True,
               release_confirm: typing.Union[bool, typing.Any] = False,
               use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Slide an edge loop along a mesh

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param single_side: Single Side
    :type single_side: typing.Union[bool, typing.Any]
    :param use_even: Even, Make the edge loop match the shape of the adjacent edge loop
    :type use_even: typing.Union[bool, typing.Any]
    :param flipped: Flipped, When Even mode is active, flips between the two adjacent edge loops
    :type flipped: typing.Union[bool, typing.Any]
    :param use_clamp: Clamp, Clamp within the edge extents
    :type use_clamp: typing.Union[bool, typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Union[bool, typing.Any]
    :param snap_target: Snap With
    :type snap_target: typing.Union[str, int]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Union[bool, typing.Any]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Union[bool, typing.Any]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Union[bool, typing.Any]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Union[bool, typing.Any]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param correct_uv: Correct UVs, Correct UV coordinates when transforming
    :type correct_uv: typing.Union[bool, typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def from_gizmo(override_context: typing.
               Union[typing.Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
               undo: typing.Optional[bool] = None):
    ''' Transform selected items by mode type

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def mirror(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        orient_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
        constraint_axis: typing.Union[typing.List[bool], typing.Any] = (False,
                                                                        False,
                                                                        False),
        gpencil_strokes: typing.Union[bool, typing.Any] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Union[bool, typing.Any] = False,
        use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Mirror selected items around one or more axes

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Union[str, int, typing.Any]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Union[str, int, typing.Any]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Union[typing.List[bool], typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Union[bool, typing.Any]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def push_pull(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        mirror: typing.Union[bool, typing.Any] = False,
        use_proportional_edit: typing.Union[bool, typing.Any] = False,
        proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Union[bool, typing.Any] = False,
        use_proportional_projected: typing.Union[bool, typing.Any] = False,
        snap: typing.Union[bool, typing.Any] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Union[bool, typing.Any] = False,
        use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Push/Pull selected items

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Distance
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Union[bool, typing.Any]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Union[str, int]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Union[bool, typing.Any]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def resize(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = (1.0, 1.0, 1.0),
        mouse_dir_constraint: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        orient_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
        constraint_axis: typing.Union[typing.List[bool], typing.Any] = (False,
                                                                        False,
                                                                        False),
        mirror: typing.Union[bool, typing.Any] = False,
        use_proportional_edit: typing.Union[bool, typing.Any] = False,
        proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Union[bool, typing.Any] = False,
        use_proportional_projected: typing.Union[bool, typing.Any] = False,
        snap: typing.Union[bool, typing.Any] = False,
        snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
        use_snap_project: typing.Union[bool, typing.Any] = False,
        snap_target: typing.Union[str, int] = 'CLOSEST',
        use_snap_self: typing.Union[bool, typing.Any] = True,
        use_snap_edit: typing.Union[bool, typing.Any] = True,
        use_snap_nonedit: typing.Union[bool, typing.Any] = True,
        use_snap_selectable: typing.Union[bool, typing.Any] = False,
        snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        gpencil_strokes: typing.Union[bool, typing.Any] = False,
        texture_space: typing.Union[bool, typing.Any] = False,
        remove_on_cancel: typing.Union[bool, typing.Any] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Union[bool, typing.Any] = False,
        use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Scale (resize) selected items

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Scale
    :type value: typing.Optional[typing.Any]
    :param mouse_dir_constraint: Mouse Directional Constraint
    :type mouse_dir_constraint: typing.Optional[typing.Any]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Union[str, int, typing.Any]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Union[str, int, typing.Any]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Union[typing.List[bool], typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Union[bool, typing.Any]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Union[str, int]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Union[bool, typing.Any]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Union[bool, typing.Any]
    :param snap_target: Snap With
    :type snap_target: typing.Union[str, int]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Union[bool, typing.Any]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Union[bool, typing.Any]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Union[bool, typing.Any]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Union[bool, typing.Any]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Union[bool, typing.Any]
    :param texture_space: Edit Texture Space, Edit object data texture space
    :type texture_space: typing.Union[bool, typing.Any]
    :param remove_on_cancel: Remove on Cancel, Remove elements on cancel
    :type remove_on_cancel: typing.Union[bool, typing.Any]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def rotate(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        orient_axis: typing.Union[str, int] = 'Z',
        orient_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
        constraint_axis: typing.Union[typing.List[bool], typing.Any] = (False,
                                                                        False,
                                                                        False),
        mirror: typing.Union[bool, typing.Any] = False,
        use_proportional_edit: typing.Union[bool, typing.Any] = False,
        proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Union[bool, typing.Any] = False,
        use_proportional_projected: typing.Union[bool, typing.Any] = False,
        snap: typing.Union[bool, typing.Any] = False,
        snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
        use_snap_project: typing.Union[bool, typing.Any] = False,
        snap_target: typing.Union[str, int] = 'CLOSEST',
        use_snap_self: typing.Union[bool, typing.Any] = True,
        use_snap_edit: typing.Union[bool, typing.Any] = True,
        use_snap_nonedit: typing.Union[bool, typing.Any] = True,
        use_snap_selectable: typing.Union[bool, typing.Any] = False,
        snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        gpencil_strokes: typing.Union[bool, typing.Any] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Union[bool, typing.Any] = False,
        use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Rotate selected items

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param orient_axis: Axis
    :type orient_axis: typing.Union[str, int]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Union[str, int, typing.Any]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Union[str, int, typing.Any]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Union[typing.List[bool], typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Union[bool, typing.Any]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Union[str, int]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Union[bool, typing.Any]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Union[bool, typing.Any]
    :param snap_target: Snap With
    :type snap_target: typing.Union[str, int]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Union[bool, typing.Any]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Union[bool, typing.Any]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Union[bool, typing.Any]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Union[bool, typing.Any]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Union[bool, typing.Any]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def rotate_normal(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        orient_axis: typing.Union[str, int] = 'Z',
        orient_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
        constraint_axis: typing.Union[typing.List[bool], typing.Any] = (False,
                                                                        False,
                                                                        False),
        mirror: typing.Union[bool, typing.Any] = False,
        release_confirm: typing.Union[bool, typing.Any] = False,
        use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Rotate split normal of selected items

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param orient_axis: Axis
    :type orient_axis: typing.Union[str, int]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Union[str, int, typing.Any]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Union[str, int, typing.Any]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Union[typing.List[bool], typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def select_orientation(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        orientation: typing.Union[str, int, typing.Any] = 'GLOBAL'):
    ''' Select transformation orientation

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param orientation: Orientation, Transformation orientation
    :type orientation: typing.Union[str, int, typing.Any]
    '''

    pass


def seq_slide(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
              undo: typing.Optional[bool] = None,
              *,
              value: typing.Optional[typing.Any] = (0.0, 0.0),
              orient_axis_ortho: typing.Union[str, int] = 'X',
              snap: typing.Union[bool, typing.Any] = False,
              view2d_edge_pan: typing.Union[bool, typing.Any] = False,
              release_confirm: typing.Union[bool, typing.Any] = False,
              use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Slide a sequence strip in time

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Offset
    :type value: typing.Optional[typing.Any]
    :param orient_axis_ortho: Axis Ortho
    :type orient_axis_ortho: typing.Union[str, int]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param view2d_edge_pan: Edge Pan, Enable edge panning in 2D view
    :type view2d_edge_pan: typing.Union[bool, typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def shear(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
          undo: typing.Optional[bool] = None,
          *,
          value: typing.Optional[typing.Any] = 0.0,
          orient_axis: typing.Union[str, int] = 'Z',
          orient_axis_ortho: typing.Union[str, int] = 'X',
          orient_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
          orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                         0.0), (0.0, 0.0, 0.0),
                                                        (0.0, 0.0, 0.0)),
          orient_matrix_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
          mirror: typing.Union[bool, typing.Any] = False,
          use_proportional_edit: typing.Union[bool, typing.Any] = False,
          proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
          proportional_size: typing.Optional[typing.Any] = 1.0,
          use_proportional_connected: typing.Union[bool, typing.Any] = False,
          use_proportional_projected: typing.Union[bool, typing.Any] = False,
          snap: typing.Union[bool, typing.Any] = False,
          gpencil_strokes: typing.Union[bool, typing.Any] = False,
          view2d_edge_pan: typing.Union[bool, typing.Any] = False,
          release_confirm: typing.Union[bool, typing.Any] = False,
          use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Shear selected items along the horizontal screen axis

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Offset
    :type value: typing.Optional[typing.Any]
    :param orient_axis: Axis
    :type orient_axis: typing.Union[str, int]
    :param orient_axis_ortho: Axis Ortho
    :type orient_axis_ortho: typing.Union[str, int]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Union[str, int, typing.Any]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Union[str, int, typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Union[bool, typing.Any]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Union[str, int]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Union[bool, typing.Any]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Union[bool, typing.Any]
    :param view2d_edge_pan: Edge Pan, Enable edge panning in 2D view
    :type view2d_edge_pan: typing.Union[bool, typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def shrink_fatten(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        use_even_offset: typing.Union[bool, typing.Any] = False,
        mirror: typing.Union[bool, typing.Any] = False,
        use_proportional_edit: typing.Union[bool, typing.Any] = False,
        proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Union[bool, typing.Any] = False,
        use_proportional_projected: typing.Union[bool, typing.Any] = False,
        snap: typing.Union[bool, typing.Any] = False,
        release_confirm: typing.Union[bool, typing.Any] = False,
        use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Shrink/fatten selected vertices along normals

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Offset
    :type value: typing.Optional[typing.Any]
    :param use_even_offset: Offset Even, Scale the offset to give more even thickness
    :type use_even_offset: typing.Union[bool, typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Union[bool, typing.Any]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Union[str, int]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Union[bool, typing.Any]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def skin_resize(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = (1.0, 1.0, 1.0),
        orient_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Union[str, int, typing.Any] = 'GLOBAL',
        constraint_axis: typing.Union[typing.List[bool], typing.Any] = (False,
                                                                        False,
                                                                        False),
        mirror: typing.Union[bool, typing.Any] = False,
        use_proportional_edit: typing.Union[bool, typing.Any] = False,
        proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Union[bool, typing.Any] = False,
        use_proportional_projected: typing.Union[bool, typing.Any] = False,
        snap: typing.Union[bool, typing.Any] = False,
        snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
        use_snap_project: typing.Union[bool, typing.Any] = False,
        snap_target: typing.Union[str, int] = 'CLOSEST',
        use_snap_self: typing.Union[bool, typing.Any] = True,
        use_snap_edit: typing.Union[bool, typing.Any] = True,
        use_snap_nonedit: typing.Union[bool, typing.Any] = True,
        use_snap_selectable: typing.Union[bool, typing.Any] = False,
        snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Union[bool, typing.Any] = False,
        use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Scale selected vertices' skin radii

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Scale
    :type value: typing.Optional[typing.Any]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Union[str, int, typing.Any]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Union[str, int, typing.Any]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Union[typing.List[bool], typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Union[bool, typing.Any]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Union[str, int]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Union[bool, typing.Any]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Union[bool, typing.Any]
    :param snap_target: Snap With
    :type snap_target: typing.Union[str, int]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Union[bool, typing.Any]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Union[bool, typing.Any]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Union[bool, typing.Any]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Union[bool, typing.Any]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def tilt(override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
         undo: typing.Optional[bool] = None,
         *,
         value: typing.Optional[typing.Any] = 0.0,
         mirror: typing.Union[bool, typing.Any] = False,
         use_proportional_edit: typing.Union[bool, typing.Any] = False,
         proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
         proportional_size: typing.Optional[typing.Any] = 1.0,
         use_proportional_connected: typing.Union[bool, typing.Any] = False,
         use_proportional_projected: typing.Union[bool, typing.Any] = False,
         snap: typing.Union[bool, typing.Any] = False,
         release_confirm: typing.Union[bool, typing.Any] = False,
         use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Tilt selected control vertices of 3D curve

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Union[bool, typing.Any]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Union[str, int]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Union[bool, typing.Any]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def tosphere(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        mirror: typing.Union[bool, typing.Any] = False,
        use_proportional_edit: typing.Union[bool, typing.Any] = False,
        proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Union[bool, typing.Any] = False,
        use_proportional_projected: typing.Union[bool, typing.Any] = False,
        snap: typing.Union[bool, typing.Any] = False,
        gpencil_strokes: typing.Union[bool, typing.Any] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Union[bool, typing.Any] = False,
        use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Move selected items outward in a spherical shape around geometric center

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Union[bool, typing.Any]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Union[str, int]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Union[bool, typing.Any]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Union[bool, typing.Any]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def trackball(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = (0.0, 0.0),
        mirror: typing.Union[bool, typing.Any] = False,
        use_proportional_edit: typing.Union[bool, typing.Any] = False,
        proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Union[bool, typing.Any] = False,
        use_proportional_projected: typing.Union[bool, typing.Any] = False,
        snap: typing.Union[bool, typing.Any] = False,
        gpencil_strokes: typing.Union[bool, typing.Any] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Union[bool, typing.Any] = False,
        use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Trackball style rotation of selected items

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Union[bool, typing.Any]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Union[str, int]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Union[bool, typing.Any]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Union[bool, typing.Any]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def transform(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        mode: typing.Union[str, int] = 'TRANSLATION',
        value: typing.Optional[typing.Any] = (0.0, 0.0, 0.0, 0.0),
        orient_axis: typing.Union[str, int] = 'Z',
        orient_type: typing.Union[str, int] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Union[str, int] = 'GLOBAL',
        constraint_axis: typing.Union[typing.List[bool], typing.Any] = (False,
                                                                        False,
                                                                        False),
        mirror: typing.Union[bool, typing.Any] = False,
        use_proportional_edit: typing.Union[bool, typing.Any] = False,
        proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Union[bool, typing.Any] = False,
        use_proportional_projected: typing.Union[bool, typing.Any] = False,
        snap: typing.Union[bool, typing.Any] = False,
        snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
        use_snap_project: typing.Union[bool, typing.Any] = False,
        snap_target: typing.Union[str, int] = 'CLOSEST',
        use_snap_self: typing.Union[bool, typing.Any] = True,
        use_snap_edit: typing.Union[bool, typing.Any] = True,
        use_snap_nonedit: typing.Union[bool, typing.Any] = True,
        use_snap_selectable: typing.Union[bool, typing.Any] = False,
        snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        snap_align: typing.Union[bool, typing.Any] = False,
        snap_normal: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        gpencil_strokes: typing.Union[bool, typing.Any] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Union[bool, typing.Any] = False,
        use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Transform selected items by mode type

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param mode: Mode
    :type mode: typing.Union[str, int]
    :param value: Values
    :type value: typing.Optional[typing.Any]
    :param orient_axis: Axis
    :type orient_axis: typing.Union[str, int]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Union[str, int]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Union[str, int]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Union[typing.List[bool], typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Union[bool, typing.Any]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Union[str, int]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Union[bool, typing.Any]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Union[bool, typing.Any]
    :param snap_target: Snap With
    :type snap_target: typing.Union[str, int]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Union[bool, typing.Any]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Union[bool, typing.Any]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Union[bool, typing.Any]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Union[bool, typing.Any]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param snap_align: Align with Point Normal
    :type snap_align: typing.Union[bool, typing.Any]
    :param snap_normal: Normal
    :type snap_normal: typing.Optional[typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Union[bool, typing.Any]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def translate(
        override_context: typing.Union[typing.
                                       Dict, 'bpy.types.Context'] = None,
        execution_context: typing.Union[str, int] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        orient_axis_ortho: typing.Union[str, int] = 'X',
        orient_type: typing.Union[str, int] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Union[str, int] = 'GLOBAL',
        constraint_axis: typing.Union[typing.List[bool], typing.Any] = (False,
                                                                        False,
                                                                        False),
        mirror: typing.Union[bool, typing.Any] = False,
        use_proportional_edit: typing.Union[bool, typing.Any] = False,
        proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Union[bool, typing.Any] = False,
        use_proportional_projected: typing.Union[bool, typing.Any] = False,
        snap: typing.Union[bool, typing.Any] = False,
        snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
        use_snap_project: typing.Union[bool, typing.Any] = False,
        snap_target: typing.Union[str, int] = 'CLOSEST',
        use_snap_self: typing.Union[bool, typing.Any] = True,
        use_snap_edit: typing.Union[bool, typing.Any] = True,
        use_snap_nonedit: typing.Union[bool, typing.Any] = True,
        use_snap_selectable: typing.Union[bool, typing.Any] = False,
        snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        snap_align: typing.Union[bool, typing.Any] = False,
        snap_normal: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        gpencil_strokes: typing.Union[bool, typing.Any] = False,
        cursor_transform: typing.Union[bool, typing.Any] = False,
        texture_space: typing.Union[bool, typing.Any] = False,
        remove_on_cancel: typing.Union[bool, typing.Any] = False,
        view2d_edge_pan: typing.Union[bool, typing.Any] = False,
        release_confirm: typing.Union[bool, typing.Any] = False,
        use_accurate: typing.Union[bool, typing.Any] = False,
        use_automerge_and_split: typing.Union[bool, typing.Any] = False):
    ''' Move selected items

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Move
    :type value: typing.Optional[typing.Any]
    :param orient_axis_ortho: Axis Ortho
    :type orient_axis_ortho: typing.Union[str, int]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Union[str, int]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Union[str, int]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Union[typing.List[bool], typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Union[bool, typing.Any]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Union[str, int]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Union[bool, typing.Any]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Union[bool, typing.Any]
    :param snap_target: Snap With
    :type snap_target: typing.Union[str, int]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Union[bool, typing.Any]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Union[bool, typing.Any]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Union[bool, typing.Any]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Union[bool, typing.Any]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param snap_align: Align with Point Normal
    :type snap_align: typing.Union[bool, typing.Any]
    :param snap_normal: Normal
    :type snap_normal: typing.Optional[typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Union[bool, typing.Any]
    :param cursor_transform: Transform Cursor
    :type cursor_transform: typing.Union[bool, typing.Any]
    :param texture_space: Edit Texture Space, Edit object data texture space
    :type texture_space: typing.Union[bool, typing.Any]
    :param remove_on_cancel: Remove on Cancel, Remove elements on cancel
    :type remove_on_cancel: typing.Union[bool, typing.Any]
    :param view2d_edge_pan: Edge Pan, Enable edge panning in 2D view
    :type view2d_edge_pan: typing.Union[bool, typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    :param use_automerge_and_split: Auto Merge & Split, Forces the use of Auto Merge and Split
    :type use_automerge_and_split: typing.Union[bool, typing.Any]
    '''

    pass


def vert_crease(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
                undo: typing.Optional[bool] = None,
                *,
                value: typing.Optional[typing.Any] = 0.0,
                snap: typing.Union[bool, typing.Any] = False,
                release_confirm: typing.Union[bool, typing.Any] = False,
                use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Change the crease of vertices

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def vert_slide(override_context: typing.
               Union[typing.Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
               undo: typing.Optional[bool] = None,
               *,
               value: typing.Optional[typing.Any] = 0.0,
               use_even: typing.Union[bool, typing.Any] = False,
               flipped: typing.Union[bool, typing.Any] = False,
               use_clamp: typing.Union[bool, typing.Any] = True,
               mirror: typing.Union[bool, typing.Any] = False,
               snap: typing.Union[bool, typing.Any] = False,
               snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
               use_snap_project: typing.Union[bool, typing.Any] = False,
               snap_target: typing.Union[str, int] = 'CLOSEST',
               use_snap_self: typing.Union[bool, typing.Any] = True,
               use_snap_edit: typing.Union[bool, typing.Any] = True,
               use_snap_nonedit: typing.Union[bool, typing.Any] = True,
               use_snap_selectable: typing.Union[bool, typing.Any] = False,
               snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
               correct_uv: typing.Union[bool, typing.Any] = True,
               release_confirm: typing.Union[bool, typing.Any] = False,
               use_accurate: typing.Union[bool, typing.Any] = False):
    ''' Slide a vertex along a mesh

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param use_even: Even, Make the edge loop match the shape of the adjacent edge loop
    :type use_even: typing.Union[bool, typing.Any]
    :param flipped: Flipped, When Even mode is active, flips between the two adjacent edge loops
    :type flipped: typing.Union[bool, typing.Any]
    :param use_clamp: Clamp, Clamp within the edge extents
    :type use_clamp: typing.Union[bool, typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Union[bool, typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Union[bool, typing.Any]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Union[bool, typing.Any]
    :param snap_target: Snap With
    :type snap_target: typing.Union[str, int]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Union[bool, typing.Any]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Union[bool, typing.Any]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Union[bool, typing.Any]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Union[bool, typing.Any]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param correct_uv: Correct UVs, Correct UV coordinates when transforming
    :type correct_uv: typing.Union[bool, typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Union[bool, typing.Any]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Union[bool, typing.Any]
    '''

    pass


def vertex_random(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
                  undo: typing.Optional[bool] = None,
                  *,
                  offset: typing.Optional[typing.Any] = 0.0,
                  uniform: typing.Optional[typing.Any] = 0.0,
                  normal: typing.Optional[typing.Any] = 0.0,
                  seed: typing.Optional[typing.Any] = 0,
                  wait_for_input: typing.Union[bool, typing.Any] = True):
    ''' Randomize vertices

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param offset: Amount, Distance to offset
    :type offset: typing.Optional[typing.Any]
    :param uniform: Uniform, Increase for uniform offset distance
    :type uniform: typing.Optional[typing.Any]
    :param normal: Normal, Align offset direction to normals
    :type normal: typing.Optional[typing.Any]
    :param seed: Random Seed, Seed for the random number generator
    :type seed: typing.Optional[typing.Any]
    :param wait_for_input: Wait for Input
    :type wait_for_input: typing.Union[bool, typing.Any]
    '''

    pass


def vertex_warp(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
                undo: typing.Optional[bool] = None,
                *,
                warp_angle: typing.Optional[typing.Any] = 6.28319,
                offset_angle: typing.Optional[typing.Any] = 0.0,
                min: typing.Optional[typing.Any] = -1.0,
                max: typing.Optional[typing.Any] = 1.0,
                viewmat: typing.Optional[typing.Any] = ((0.0, 0.0, 0.0, 0.0),
                                                        (0.0, 0.0, 0.0, 0.0),
                                                        (0.0, 0.0, 0.0,
                                                         0.0), (0.0, 0.0, 0.0,
                                                                0.0)),
                center: typing.Optional[typing.Any] = (0.0, 0.0, 0.0)):
    ''' Warp vertices around the cursor

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param warp_angle: Warp Angle, Amount to warp about the cursor
    :type warp_angle: typing.Optional[typing.Any]
    :param offset_angle: Offset Angle, Angle to use as the basis for warping
    :type offset_angle: typing.Optional[typing.Any]
    :param min: Min
    :type min: typing.Optional[typing.Any]
    :param max: Max
    :type max: typing.Optional[typing.Any]
    :param viewmat: Matrix
    :type viewmat: typing.Optional[typing.Any]
    :param center: Center
    :type center: typing.Optional[typing.Any]
    '''

    pass



import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def autocomplete(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
                 undo: typing.Optional[bool] = None):
    ''' Evaluate the namespace up until the cursor and give a list of options or complete the name if there is only one :file:`startup/bl_operators/console.py\:56 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/console.py#L56>`_

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def banner(override_context: typing.Union[typing.
                                          Dict, 'bpy.types.Context'] = None,
           execution_context: typing.Union[str, int] = None,
           undo: typing.Optional[bool] = None):
    ''' Print a message when the terminal initializes :file:`startup/bl_operators/console.py\:101 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/console.py#L101>`_

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def clear(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
          undo: typing.Optional[bool] = None,
          *,
          scrollback: typing.Union[bool, typing.Any] = True,
          history: typing.Union[bool, typing.Any] = False):
    ''' Clear text by type

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param scrollback: Scrollback, Clear the scrollback history
    :type scrollback: typing.Union[bool, typing.Any]
    :param history: History, Clear the command history
    :type history: typing.Union[bool, typing.Any]
    '''

    pass


def clear_line(override_context: typing.
               Union[typing.Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
               undo: typing.Optional[bool] = None):
    ''' Clear the line and store in history

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def copy(override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
         undo: typing.Optional[bool] = None):
    ''' Copy selected text to clipboard

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def copy_as_script(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
                   undo: typing.Optional[bool] = None):
    ''' Copy the console contents for use in a script :file:`startup/bl_operators/console.py\:78 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/console.py#L78>`_

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def delete(override_context: typing.Union[typing.
                                          Dict, 'bpy.types.Context'] = None,
           execution_context: typing.Union[str, int] = None,
           undo: typing.Optional[bool] = None,
           *,
           type: typing.Optional[typing.Any] = 'NEXT_CHARACTER'):
    ''' Delete text by cursor position

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param type: Type, Which part of the text to delete
    :type type: typing.Optional[typing.Any]
    '''

    pass


def execute(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
            undo: typing.Optional[bool] = None,
            *,
            interactive: typing.Union[bool, typing.Any] = False):
    ''' Execute the current console line as a python expression

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param interactive: interactive
    :type interactive: typing.Union[bool, typing.Any]
    '''

    pass


def history_append(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
                   undo: typing.Optional[bool] = None,
                   *,
                   text: typing.Union[str, typing.Any] = "",
                   current_character: typing.Optional[typing.Any] = 0,
                   remove_duplicates: typing.Union[bool, typing.Any] = False):
    ''' Append history at cursor position

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param text: Text, Text to insert at the cursor position
    :type text: typing.Union[str, typing.Any]
    :param current_character: Cursor, The index of the cursor
    :type current_character: typing.Optional[typing.Any]
    :param remove_duplicates: Remove Duplicates, Remove duplicate items in the history
    :type remove_duplicates: typing.Union[bool, typing.Any]
    '''

    pass


def history_cycle(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
                  undo: typing.Optional[bool] = None,
                  *,
                  reverse: typing.Union[bool, typing.Any] = False):
    ''' Cycle through history

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param reverse: Reverse, Reverse cycle history
    :type reverse: typing.Union[bool, typing.Any]
    '''

    pass


def indent(override_context: typing.Union[typing.
                                          Dict, 'bpy.types.Context'] = None,
           execution_context: typing.Union[str, int] = None,
           undo: typing.Optional[bool] = None):
    ''' Add 4 spaces at line beginning

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def indent_or_autocomplete(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
                           undo: typing.Optional[bool] = None):
    ''' Indent selected text or autocomplete

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def insert(override_context: typing.Union[typing.
                                          Dict, 'bpy.types.Context'] = None,
           execution_context: typing.Union[str, int] = None,
           undo: typing.Optional[bool] = None,
           *,
           text: typing.Union[str, typing.Any] = ""):
    ''' Insert text at cursor position

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param text: Text, Text to insert at the cursor position
    :type text: typing.Union[str, typing.Any]
    '''

    pass


def language(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
             undo: typing.Optional[bool] = None,
             *,
             language: typing.Union[str, typing.Any] = ""):
    ''' Set the current language for this console

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param language: Language
    :type language: typing.Union[str, typing.Any]
    '''

    pass


def move(override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
         undo: typing.Optional[bool] = None,
         *,
         type: typing.Optional[typing.Any] = 'LINE_BEGIN'):
    ''' Move cursor position

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param type: Type, Where to move cursor to
    :type type: typing.Optional[typing.Any]
    '''

    pass


def paste(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
          undo: typing.Optional[bool] = None,
          *,
          selection: typing.Union[bool, typing.Any] = False):
    ''' Paste text from clipboard

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param selection: Selection, Paste text selected elsewhere rather than copied (X11/Wayland only)
    :type selection: typing.Union[bool, typing.Any]
    '''

    pass


def scrollback_append(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
                      undo: typing.Optional[bool] = None,
                      *,
                      text: typing.Union[str, typing.Any] = "",
                      type: typing.Optional[typing.Any] = 'OUTPUT'):
    ''' Append scrollback text by type

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param text: Text, Text to insert at the cursor position
    :type text: typing.Union[str, typing.Any]
    :param type: Type, Console output type
    :type type: typing.Optional[typing.Any]
    '''

    pass


def select_set(override_context: typing.
               Union[typing.Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
               undo: typing.Optional[bool] = None):
    ''' Set the console selection

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def select_word(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
                undo: typing.Optional[bool] = None):
    ''' Select word at cursor position

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def unindent(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
             undo: typing.Optional[bool] = None):
    ''' Delete 4 spaces from line beginning

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass



import sys
import typing
import bpy.types
import mathutils
import bpy

GenericType = typing.TypeVar("GenericType")


class AddObjectHelper:
    def align_update_callback(self, _context):
        ''' 

        '''
        pass


def add_object_align_init(
        context: 'bpy.types.Context',
        operator: 'bpy.types.Operator') -> 'mathutils.Matrix':
    ''' Return a matrix using the operator settings and view context.

    :param context: The context to use.
    :type context: 'bpy.types.Context'
    :param operator: The operator, checked for location and rotation properties.
    :type operator: 'bpy.types.Operator'
    :rtype: 'mathutils.Matrix'
    :return: the matrix from the context and settings.
    '''

    pass


def object_add_grid_scale(context):
    ''' Return scale which should be applied on object data to align it to grid scale

    '''

    pass


def object_add_grid_scale_apply_operator(operator, context):
    ''' Scale an operators distance values by the grid size.

    '''

    pass


def object_data_add(context: 'bpy.types.Context',
                    obdata: 'bpy.data',
                    operator: 'bpy.types.Operator' = None,
                    name: str = None) -> 'bpy.types.Object':
    ''' Add an object using the view context and preference to initialize the location, rotation and layer.

    :param context: The context to use.
    :type context: 'bpy.types.Context'
    :param obdata: the data used for the new object.
    :type obdata: 'bpy.data'
    :param operator: The operator, checked for location and rotation properties.
    :type operator: 'bpy.types.Operator'
    :param name: Optional name
    :type name: str
    :rtype: 'bpy.types.Object'
    :return: the newly created object in the scene.
    '''

    pass


def world_to_camera_view(
        scene: 'bpy.types.Scene', obj: 'bpy.types.Object',
        coord: typing.Union[typing.Sequence[float], 'mathutils.Vector']
) -> 'mathutils.Vector':
    ''' Returns the camera space coords for a 3d point. (also known as: normalized device coordinates - NDC). Where (0, 0) is the bottom left and (1, 1) is the top right of the camera frame. values outside 0-1 are also supported. A negative 'z' value means the point is behind the camera. Takes shift-x/y, lens angle and sensor size into account as well as perspective/ortho projections.

    :param scene: Scene to use for frame size.
    :type scene: 'bpy.types.Scene'
    :param obj: Camera object.
    :type obj: 'bpy.types.Object'
    :param coord: World space location.
    :type coord: typing.Union[typing.Sequence[float], 'mathutils.Vector']
    :rtype: 'mathutils.Vector'
    :return: a vector where X and Y map to the view plane and Z is the depth on the view axis.
    '''

    pass



import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def flip(override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
         undo: typing.Optional[bool] = None,
         *,
         axis: typing.Optional[typing.Any] = 'U'):
    ''' Mirror all control points without inverting the lattice deform

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param axis: Flip Axis, Coordinates along this axis get flipped
    :type axis: typing.Optional[typing.Any]
    '''

    pass


def make_regular(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
                 undo: typing.Optional[bool] = None):
    ''' Set UVW control points a uniform distance apart

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def select_all(override_context: typing.
               Union[typing.Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
               undo: typing.Optional[bool] = None,
               *,
               action: typing.Optional[typing.Any] = 'TOGGLE'):
    ''' Change selection of all UVW control points

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle -- Toggle selection for all elements. * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements. * ``INVERT`` Invert -- Invert selection of all elements.
    :type action: typing.Optional[typing.Any]
    '''

    pass


def select_less(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
                undo: typing.Optional[bool] = None):
    ''' Deselect vertices at the boundary of each selection region

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def select_mirror(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
                  undo: typing.Optional[bool] = None,
                  *,
                  axis: typing.Optional[typing.Any] = {'X'},
                  extend: typing.Union[bool, typing.Any] = False):
    ''' Select mirrored lattice points

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param axis: Axis
    :type axis: typing.Optional[typing.Any]
    :param extend: Extend, Extend the selection
    :type extend: typing.Union[bool, typing.Any]
    '''

    pass


def select_more(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
                undo: typing.Optional[bool] = None):
    ''' Select vertex directly linked to already selected ones

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def select_random(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
                  undo: typing.Optional[bool] = None,
                  *,
                  ratio: typing.Optional[typing.Any] = 0.5,
                  seed: typing.Optional[typing.Any] = 0,
                  action: typing.Optional[typing.Any] = 'SELECT'):
    ''' Randomly select UVW control points

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param ratio: Ratio, Portion of items to select randomly
    :type ratio: typing.Optional[typing.Any]
    :param seed: Random Seed, Seed for the random number generator
    :type seed: typing.Optional[typing.Any]
    :param action: Action, Selection action to execute * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements.
    :type action: typing.Optional[typing.Any]
    '''

    pass


def select_ungrouped(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
                     undo: typing.Optional[bool] = None,
                     *,
                     extend: typing.Union[bool, typing.Any] = False):
    ''' Select vertices without a group

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param extend: Extend, Extend the selection
    :type extend: typing.Union[bool, typing.Any]
    '''

    pass



import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def bake(override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
         undo: typing.Optional[bool] = None):
    ''' Bake dynamic paint image sequence surface

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def output_toggle(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
                  undo: typing.Optional[bool] = None,
                  *,
                  output: typing.Optional[typing.Any] = 'A'):
    ''' Add or remove Dynamic Paint output data layer

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param output: Output Toggle
    :type output: typing.Optional[typing.Any]
    '''

    pass


def surface_slot_add(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
                     undo: typing.Optional[bool] = None):
    ''' Add a new Dynamic Paint surface slot

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def surface_slot_remove(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
                        undo: typing.Optional[bool] = None):
    ''' Remove the selected surface slot

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    '''

    pass


def type_toggle(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
                undo: typing.Optional[bool] = None,
                *,
                type: typing.Union[str, int] = 'CANVAS'):
    ''' Toggle whether given type is active or not

    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
    :type execution_context: typing.Union[str, int]
    :type undo: typing.Optional[bool]
    :param type: Type
    :type type: typing.Union[str, int]
    '''

    pass
